@@ -1,3 +1,4 @@
+from django.apps import apps
 from django.contrib.auth.models import BaseUserManager
 from django.db import models
 
@@ -32,3 +33,9 @@ class SubjectManager(BaseUserManager):
         by the given parameters.
         """
         return self.filter(**params).enable()
+
+    def create_user(self, kind, **kwargs):
+        Subject = apps.get_model('iam', kind)
+        if Subject is None:
+            raise ValueError(f"Invalid kind: {kind}")
+        return Subject.objects.create(**kwargs)
