@@ -4,6 +4,7 @@ from .subjects import Subject
 
 
 class User(Subject):
+
     subject = models.OneToOneField(
         Subject,
         parent_link=True,
@@ -26,6 +27,11 @@ class User(Subject):
         db_column='last_name'
     )
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        if not self.kind:
+            self.kind = 'User'
+
     class Meta:
         app_label = 'iam'
         default_permissions = []
